"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .createdocumentfromurlparams import (
    CreateDocumentFromURLParams,
    CreateDocumentFromURLParamsMetadata,
    CreateDocumentFromURLParamsMetadataTypedDict,
    CreateDocumentFromURLParamsMode,
    CreateDocumentFromURLParamsTypedDict,
)
from .createdocumentparams import (
    CreateDocumentParams,
    CreateDocumentParamsTypedDict,
    File,
    FileTypedDict,
    Metadata,
    MetadataTypedDict,
    Mode,
)
from .createdocumentrawparams import (
    CreateDocumentRawParams,
    CreateDocumentRawParamsMetadata,
    CreateDocumentRawParamsMetadataTypedDict,
    CreateDocumentRawParamsTypedDict,
    Data,
    DataTypedDict,
    Two,
    TwoTypedDict,
)
from .createinstructionparams import (
    CreateInstructionParams,
    CreateInstructionParamsFilter,
    CreateInstructionParamsFilterTypedDict,
    CreateInstructionParamsScope,
    CreateInstructionParamsTypedDict,
)
from .deletedocumentop import DeleteDocumentRequest, DeleteDocumentRequestTypedDict
from .document import (
    Document,
    DocumentMetadata,
    DocumentMetadataTypedDict,
    DocumentTypedDict,
)
from .documentdelete import DocumentDelete, DocumentDeleteTypedDict
from .documentfileupdate import DocumentFileUpdate, DocumentFileUpdateTypedDict
from .documentget import (
    DocumentGet,
    DocumentGetMetadata,
    DocumentGetMetadataTypedDict,
    DocumentGetTypedDict,
)
from .documentlist import DocumentList, DocumentListTypedDict
from .documentmetadataupdate import (
    DocumentMetadataUpdate,
    DocumentMetadataUpdateMetadata,
    DocumentMetadataUpdateMetadataTypedDict,
    DocumentMetadataUpdateTypedDict,
)
from .documentrawupdate import DocumentRawUpdate, DocumentRawUpdateTypedDict
from .documentsummary import DocumentSummary, DocumentSummaryTypedDict
from .entity import Entity, EntityTypedDict
from .entitylist import EntityList, EntityListTypedDict
from .errormessage_error import ErrorMessageError, ErrorMessageErrorData
from .getdocumentop import GetDocumentRequest, GetDocumentRequestTypedDict
from .getdocumentsummaryop import (
    GetDocumentSummaryRequest,
    GetDocumentSummaryRequestTypedDict,
)
from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
from .instruction import (
    Filter,
    FilterTypedDict,
    Instruction,
    InstructionTypedDict,
    Scope,
)
from .listdocumentsop import (
    ListDocumentsRequest,
    ListDocumentsRequestTypedDict,
    ListDocumentsResponse,
    ListDocumentsResponseTypedDict,
)
from .listentitiesbydocumentop import (
    ListEntitiesByDocumentRequest,
    ListEntitiesByDocumentRequestTypedDict,
    ListEntitiesByDocumentResponse,
    ListEntitiesByDocumentResponseTypedDict,
)
from .listentitiesbyinstructionop import (
    ListEntitiesByInstructionRequest,
    ListEntitiesByInstructionRequestTypedDict,
    ListEntitiesByInstructionResponse,
    ListEntitiesByInstructionResponseTypedDict,
)
from .pagination import Pagination, PaginationTypedDict
from .patchdocumentmetadataop import (
    PatchDocumentMetadataRequest,
    PatchDocumentMetadataRequestTypedDict,
)
from .patchdocumentmetadataparams import (
    PatchDocumentMetadataParams,
    PatchDocumentMetadataParamsMetadata,
    PatchDocumentMetadataParamsMetadataTypedDict,
    PatchDocumentMetadataParamsTypedDict,
)
from .retrieval import Retrieval, RetrievalTypedDict
from .retrieveparams import RetrieveParams, RetrieveParamsTypedDict
from .scoredchunk import ScoredChunk, ScoredChunkTypedDict
from .sdkerror import SDKError
from .security import Security, SecurityTypedDict
from .updatedocumentfileop import (
    UpdateDocumentFileRequest,
    UpdateDocumentFileRequestTypedDict,
)
from .updatedocumentfileparams import (
    UpdateDocumentFileParams,
    UpdateDocumentFileParamsFile,
    UpdateDocumentFileParamsFileTypedDict,
    UpdateDocumentFileParamsMode,
    UpdateDocumentFileParamsTypedDict,
)
from .updatedocumentrawop import (
    UpdateDocumentRawRequest,
    UpdateDocumentRawRequestTypedDict,
)
from .updatedocumentrawparams import (
    Data2,
    Data2TypedDict,
    UpdateDocumentRawParams,
    UpdateDocumentRawParamsData,
    UpdateDocumentRawParamsDataTypedDict,
    UpdateDocumentRawParamsTypedDict,
)
from .updateinstructionop import (
    UpdateInstructionRequest,
    UpdateInstructionRequestTypedDict,
)
from .updateinstructionparams import (
    UpdateInstructionParams,
    UpdateInstructionParamsTypedDict,
)
from .validationerror import (
    Loc,
    LocTypedDict,
    ValidationError,
    ValidationErrorTypedDict,
)

__all__ = [
    "CreateDocumentFromURLParams",
    "CreateDocumentFromURLParamsMetadata",
    "CreateDocumentFromURLParamsMetadataTypedDict",
    "CreateDocumentFromURLParamsMode",
    "CreateDocumentFromURLParamsTypedDict",
    "CreateDocumentParams",
    "CreateDocumentParamsTypedDict",
    "CreateDocumentRawParams",
    "CreateDocumentRawParamsMetadata",
    "CreateDocumentRawParamsMetadataTypedDict",
    "CreateDocumentRawParamsTypedDict",
    "CreateInstructionParams",
    "CreateInstructionParamsFilter",
    "CreateInstructionParamsFilterTypedDict",
    "CreateInstructionParamsScope",
    "CreateInstructionParamsTypedDict",
    "Data",
    "Data2",
    "Data2TypedDict",
    "DataTypedDict",
    "DeleteDocumentRequest",
    "DeleteDocumentRequestTypedDict",
    "Document",
    "DocumentDelete",
    "DocumentDeleteTypedDict",
    "DocumentFileUpdate",
    "DocumentFileUpdateTypedDict",
    "DocumentGet",
    "DocumentGetMetadata",
    "DocumentGetMetadataTypedDict",
    "DocumentGetTypedDict",
    "DocumentList",
    "DocumentListTypedDict",
    "DocumentMetadata",
    "DocumentMetadataTypedDict",
    "DocumentMetadataUpdate",
    "DocumentMetadataUpdateMetadata",
    "DocumentMetadataUpdateMetadataTypedDict",
    "DocumentMetadataUpdateTypedDict",
    "DocumentRawUpdate",
    "DocumentRawUpdateTypedDict",
    "DocumentSummary",
    "DocumentSummaryTypedDict",
    "DocumentTypedDict",
    "Entity",
    "EntityList",
    "EntityListTypedDict",
    "EntityTypedDict",
    "ErrorMessageError",
    "ErrorMessageErrorData",
    "File",
    "FileTypedDict",
    "Filter",
    "FilterTypedDict",
    "GetDocumentRequest",
    "GetDocumentRequestTypedDict",
    "GetDocumentSummaryRequest",
    "GetDocumentSummaryRequestTypedDict",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "Instruction",
    "InstructionTypedDict",
    "ListDocumentsRequest",
    "ListDocumentsRequestTypedDict",
    "ListDocumentsResponse",
    "ListDocumentsResponseTypedDict",
    "ListEntitiesByDocumentRequest",
    "ListEntitiesByDocumentRequestTypedDict",
    "ListEntitiesByDocumentResponse",
    "ListEntitiesByDocumentResponseTypedDict",
    "ListEntitiesByInstructionRequest",
    "ListEntitiesByInstructionRequestTypedDict",
    "ListEntitiesByInstructionResponse",
    "ListEntitiesByInstructionResponseTypedDict",
    "Loc",
    "LocTypedDict",
    "Metadata",
    "MetadataTypedDict",
    "Mode",
    "Pagination",
    "PaginationTypedDict",
    "PatchDocumentMetadataParams",
    "PatchDocumentMetadataParamsMetadata",
    "PatchDocumentMetadataParamsMetadataTypedDict",
    "PatchDocumentMetadataParamsTypedDict",
    "PatchDocumentMetadataRequest",
    "PatchDocumentMetadataRequestTypedDict",
    "Retrieval",
    "RetrievalTypedDict",
    "RetrieveParams",
    "RetrieveParamsTypedDict",
    "SDKError",
    "Scope",
    "ScoredChunk",
    "ScoredChunkTypedDict",
    "Security",
    "SecurityTypedDict",
    "Two",
    "TwoTypedDict",
    "UpdateDocumentFileParams",
    "UpdateDocumentFileParamsFile",
    "UpdateDocumentFileParamsFileTypedDict",
    "UpdateDocumentFileParamsMode",
    "UpdateDocumentFileParamsTypedDict",
    "UpdateDocumentFileRequest",
    "UpdateDocumentFileRequestTypedDict",
    "UpdateDocumentRawParams",
    "UpdateDocumentRawParamsData",
    "UpdateDocumentRawParamsDataTypedDict",
    "UpdateDocumentRawParamsTypedDict",
    "UpdateDocumentRawRequest",
    "UpdateDocumentRawRequestTypedDict",
    "UpdateInstructionParams",
    "UpdateInstructionParamsTypedDict",
    "UpdateInstructionRequest",
    "UpdateInstructionRequestTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import Dict, List, Union
from typing_extensions import TypedDict


PatchDocumentMetadataParamsMetadataTypedDict = Union[str, int, bool, List[str]]


PatchDocumentMetadataParamsMetadata = Union[str, int, bool, List[str]]


class PatchDocumentMetadataParamsTypedDict(TypedDict):
    metadata: Dict[str, PatchDocumentMetadataParamsMetadataTypedDict]
    r"""The metadata to update on the document. Performs a partial update of the document's metadata. Keys must be strings. Values may be strings, numbers, booleans, or lists of strings. Numbers may be integers or floating point and will be converted to 64 bit floating point. Keys set to `null` are deleted. 1000 total values are allowed, inclusive of existing metadata. Each item in an array counts towards the total. The following keys are reserved for internal use: `document_id`, `document_type`, `document_source`, `document_name`, `document_uploaded_at`, `__ragie__document_version_id`, `__ragie__chunk_size_chars`, `__ragie__chunk_overlap_chars`, `__ragie__partition`."""


class PatchDocumentMetadataParams(BaseModel):
    metadata: Dict[str, PatchDocumentMetadataParamsMetadata]
    r"""The metadata to update on the document. Performs a partial update of the document's metadata. Keys must be strings. Values may be strings, numbers, booleans, or lists of strings. Numbers may be integers or floating point and will be converted to 64 bit floating point. Keys set to `null` are deleted. 1000 total values are allowed, inclusive of existing metadata. Each item in an array counts towards the total. The following keys are reserved for internal use: `document_id`, `document_type`, `document_source`, `document_name`, `document_uploaded_at`, `__ragie__document_version_id`, `__ragie__chunk_size_chars`, `__ragie__chunk_overlap_chars`, `__ragie__partition`."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from .pagination import Pagination, PaginationTypedDict
from ragie.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class DocumentListTypedDict(TypedDict):
    pagination: PaginationTypedDict
    documents: List[DocumentTypedDict]


class DocumentList(BaseModel):
    pagination: Pagination

    documents: List[Document]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .entity import Entity, EntityTypedDict
from .pagination import Pagination, PaginationTypedDict
from ragie.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class EntityListTypedDict(TypedDict):
    pagination: PaginationTypedDict
    entities: List[EntityTypedDict]


class EntityList(BaseModel):
    pagination: Pagination

    entities: List[Entity]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from ragie.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class EntityTypedDict(TypedDict):
    id: str
    created_at: datetime
    updated_at: datetime
    instruction_id: str
    r"""The ID of the instruction which generated the entity."""
    document_id: str
    r"""The ID of the document which the entity was produced from."""
    data: Dict[str, Any]
    r"""The entity data generated by the instruction."""


class Entity(BaseModel):
    id: str

    created_at: datetime

    updated_at: datetime

    instruction_id: str
    r"""The ID of the instruction which generated the entity."""

    document_id: str
    r"""The ID of the document which the entity was produced from."""

    data: Dict[str, Any]
    r"""The entity data generated by the instruction."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
import io
import pydantic
from ragie.types import BaseModel
from ragie.utils import FieldMetadata, MultipartFormMetadata
from typing import Dict, IO, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class Mode(str, Enum):
    r"""Partition strategy for the document. Options are `'hi_res'` or `'fast'`. Only applicable for rich documents such as word documents and PDFs. When set to `'hi_res'`, images and tables will be extracted from the document. `'fast'` will only extract text. `'fast'` may be up to 20x faster than `'hi_res'`."""

    HI_RES = "hi_res"
    FAST = "fast"


MetadataTypedDict = Union[str, float, bool, List[str]]


Metadata = Union[str, float, bool, List[str]]


class FileTypedDict(TypedDict):
    file_name: str
    content: Union[bytes, IO[bytes], io.BufferedReader]
    content_type: NotRequired[str]


class File(BaseModel):
    file_name: Annotated[
        str, pydantic.Field(alias="file"), FieldMetadata(multipart=True)
    ]

    content: Annotated[
        Union[bytes, IO[bytes], io.BufferedReader],
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(content=True)),
    ]

    content_type: Annotated[
        Optional[str],
        pydantic.Field(alias="Content-Type"),
        FieldMetadata(multipart=True),
    ] = None


class CreateDocumentParamsTypedDict(TypedDict):
    file: FileTypedDict
    r"""The binary file to upload, extract, and index for retrieval. The following file types are supported: Plain Text: `.eml` `.html` `.json` `.md` `.msg` `.rst` `.rtf` `.txt` `.xml`
    Images: `.png` `.webp` `.jpg` `.jpeg` `.tiff` `.bmp` `.heic`
    Documents: `.csv` `.doc` `.docx` `.epub` `.epub+zip` `.odt` `.pdf` `.ppt` `.pptx` `.tsv` `.xlsx` `.xls`.
    """
    mode: NotRequired[Mode]
    r"""Partition strategy for the document. Options are `'hi_res'` or `'fast'`. Only applicable for rich documents such as word documents and PDFs. When set to `'hi_res'`, images and tables will be extracted from the document. `'fast'` will only extract text. `'fast'` may be up to 20x faster than `'hi_res'`."""
    metadata: NotRequired[Dict[str, MetadataTypedDict]]
    r"""Metadata for the document. Keys must be strings. Values may be strings, numbers, booleans, or lists of strings. Numbers may be integers or floating point and will be converted to 64 bit floating point. 1000 total values are allowed. Each item in an array counts towards the total. The following keys are reserved for internal use: `document_id`, `document_type`, `document_source`, `document_name`, `document_uploaded_at`."""
    external_id: NotRequired[str]
    r"""An optional identifier for the document. A common value might be an id in an external system or the URL where the source file may be found."""
    partition: NotRequired[str]
    r"""An optional partition identifier. Documents can be scoped to a partition. A partition is created any time a document is created or moved to a new partition."""


class CreateDocumentParams(BaseModel):
    file: Annotated[
        File,
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(file=True)),
    ]
    r"""The binary file to upload, extract, and index for retrieval. The following file types are supported: Plain Text: `.eml` `.html` `.json` `.md` `.msg` `.rst` `.rtf` `.txt` `.xml`
    Images: `.png` `.webp` `.jpg` `.jpeg` `.tiff` `.bmp` `.heic`
    Documents: `.csv` `.doc` `.docx` `.epub` `.epub+zip` `.odt` `.pdf` `.ppt` `.pptx` `.tsv` `.xlsx` `.xls`.
    """

    mode: Annotated[Optional[Mode], FieldMetadata(multipart=True)] = Mode.FAST
    r"""Partition strategy for the document. Options are `'hi_res'` or `'fast'`. Only applicable for rich documents such as word documents and PDFs. When set to `'hi_res'`, images and tables will be extracted from the document. `'fast'` will only extract text. `'fast'` may be up to 20x faster than `'hi_res'`."""

    metadata: Annotated[
        Optional[Dict[str, Metadata]],
        FieldMetadata(multipart=MultipartFormMetadata(json=True)),
    ] = None
    r"""Metadata for the document. Keys must be strings. Values may be strings, numbers, booleans, or lists of strings. Numbers may be integers or floating point and will be converted to 64 bit floating point. 1000 total values are allowed. Each item in an array counts towards the total. The following keys are reserved for internal use: `document_id`, `document_type`, `document_source`, `document_name`, `document_uploaded_at`."""

    external_id: Annotated[Optional[str], FieldMetadata(multipart=True)] = None
    r"""An optional identifier for the document. A common value might be an id in an external system or the URL where the source file may be found."""

    partition: Annotated[Optional[str], FieldMetadata(multipart=True)] = None
    r"""An optional partition identifier. Documents can be scoped to a partition. A partition is created any time a document is created or moved to a new partition."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .updateinstructionparams import (
    UpdateInstructionParams,
    UpdateInstructionParamsTypedDict,
)
from ragie.types import BaseModel
from ragie.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateInstructionRequestTypedDict(TypedDict):
    instruction_id: str
    r"""The ID of the instruction."""
    update_instruction_params: UpdateInstructionParamsTypedDict


class UpdateInstructionRequest(BaseModel):
    instruction_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The ID of the instruction."""

    update_instruction_params: Annotated[
        UpdateInstructionParams,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import Union
from typing_extensions import TypedDict


class Data2TypedDict(TypedDict):
    pass


class Data2(BaseModel):
    pass


UpdateDocumentRawParamsDataTypedDict = Union[Data2TypedDict, str]
r"""Document data in a text or JSON format."""


UpdateDocumentRawParamsData = Union[Data2, str]
r"""Document data in a text or JSON format."""


class UpdateDocumentRawParamsTypedDict(TypedDict):
    data: UpdateDocumentRawParamsDataTypedDict
    r"""Document data in a text or JSON format."""


class UpdateDocumentRawParams(BaseModel):
    data: UpdateDocumentRawParamsData
    r"""Document data in a text or JSON format."""
